@@ -1,6 +1,6 @@
 package PMLTQ::Commands;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Commands::VERSION = '1.3.0';
+$PMLTQ::Commands::VERSION = '1.3.1';
 # ABSTRACT: PMLTQ command line interface
 
 use PMLTQ::Base -strict;
@@ -23,7 +23,10 @@ sub DEFAULT_CONFIG {
     db         => {
       host => 'localhost',
       port => 5432
-    }
+    },
+    isFree => 'false',
+    isPublic => 'false',
+    isFeatured => 'false',
   };
 }
 
@@ -166,7 +169,7 @@ PMLTQ::Commands - PMLTQ command line interface
 
 =head1 VERSION
 
-version 1.3.0
+version 1.3.1
 
 =head1 SYNOPSIS
 
@@ -176,6 +179,11 @@ version 1.3.0
     pmltq init schema1.xml schema2.xml
     pmltq convert
     pmltq load
+    pmltq initdb
+    pmltq delete
+    pmltq webload
+    pmltq webdelete
+    pmltq webverify
 
   Options (for all commands):
     -c, --config      Config file, by default commands will look
@@ -233,6 +241,18 @@ data. For now the checking is very simple
 
 Uses L<PMLTQ::Command::version> to display current PMLTQ version
 
+=head2 webdelete
+
+Uses L<PMLTQ::Command::webdelete> to delete treebank from web interface
+
+=head2 webload
+
+Uses L<PMLTQ::Command::webload> to load treebank to web interface
+
+=head2 webverify
+
+Uses L<PMLTQ::Command::webverify> to verify treebank visibility in web interface
+
 =head1 CONFIG FILE
 
 =head2 Options
@@ -242,7 +262,7 @@ Uses L<PMLTQ::Command::version> to display current PMLTQ version
 =item C<treebank_id>
 
 ID of the treebank. Can contain only [a-zA-Z0-9_]. It will be default for the
-database name.
+database name and treebank name in web interface.
 
 =item C<data_dir>
 
@@ -309,6 +329,10 @@ Schema root name
 
 A C<glob> path name matching pattern relative to C<data_dir>
 
+=item C<path>
+
+A path name matching pattern relative to PML-TQ server data directory
+
 =item C<related-schema>
 
 List of related schemas that contain node types required in this layer's
@@ -331,6 +355,98 @@ Examples:
 
 =back
 
+=item C<title>
+
+Treebank title visible at the web.
+
+=item C<homepage>
+
+Treebank homepage url.
+
+=item C<description>
+
+Treebank description visible at the web.
+
+=item C<isFree>
+
+Boolean value (C<true>, C<false>) sets if the logging in is not required for querying treebank.
+
+Defaults: B<false>
+
+=item C<isPublic>
+
+Boolean value (C<true>, C<false>) sets if the treebank is visible for not logged users.
+
+Defaults: B<false>
+
+=item C<isFeatured>
+
+Boolean value (C<true>, C<false>) sets if the treebank is featured.
+
+Defaults: B<false>
+
+=item C<web_api>
+
+=over 4
+
+=item C<dbserver>
+
+Name of database server setted in web interface.
+
+=item C<url>
+
+Link to PML-TQ web service.
+
+=item C<user>, C<password>
+
+Web API credentials of user with admin privileges.
+
+=back
+
+=item C<manuals>
+
+List of manuals
+
+=over 4
+
+=item C<title>, C<url>
+
+Title and link to manual
+
+=back
+
+=item C<tags>
+
+List of tags
+
+=item C<language>
+
+Language code
+
+=item C<test_query>
+
+=over 4
+
+=item C<result_dir>
+
+Directory where sould be saved results of test queries (SVG and text files)
+
+=item C<queries>
+
+=over 4
+
+=item C<filename>
+
+Filename where sould be the result saved
+
+=item C<query>
+
+PML-TQ query
+
+=back
+
+=back
+
 =back
 
 =head2 Change values using CLI
@@ -345,11 +461,57 @@ Dash C<-> in the parameter's name means dive into the hash, so C<--db-name='abc'
 going to change C<db: name: 'abc'> while C<--db_name='abc'> would just set configuration
 option C<db_name: 'abc'>.
 
+=head2 Commands and options
+
+Following table shows which options are used in commands.
+
+=over 4
+
+=item B<*> required
+
+=item B<+> optional (defaults or nothing is used)
+
+=item B<-> not used
+
+=back
+
+=for html <table>
+<tr><td></td><th>convert</th><th>delete</th><th>init</th><th>initdb</th><th>load</th><th>verify</th><th>webdelete</th><th>webload</th><th>webverify</th></tr>
+<tr><td>treebank_id</td><th>*</th><th>*</th><th>-</th><th>*</th><th>*</th><th>*</th><th>*</th><th>*</th><th>*</th></tr>
+<tr><td>data_dir</td><th>+</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>resources</td><th>+</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>output_dir</td><th>+</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>db-name</td><th>-</th><th>+</th><th>-</th><th>+</th><th>+</th><th>+</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>db-host</td><th>-</th><th>+</th><th>-</th><th>+</th><th>+</th><th>+</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>db-port</td><th>-</th><th>+</th><th>-</th><th>+</th><th>+</th><th>+</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>db-user</td><th>-</th><th>-</th><th>-</th><th>*</th><th>*</th><th>*</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>db-password</td><th>-</th><th>-</th><th>-</th><th>*</th><th>*</th><th>*</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>sys_db</td><th>-</th><th>*</th><th>-</th><th>*</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th></tr>
+<tr><td>layers</td><th>*</th><th>-</th><th>-</th><th>-</th><th>*</th><th>-</th><th>-</th><th>*</th><th>-</th></tr>
+<tr><td>title</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>*</th><th>-</th></tr>
+<tr><td>homepage</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>description</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>isFree</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>isPublic</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>isFeatured</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>web_api-dbserver</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>*</th><th>-</th></tr>
+<tr><td>web_api-url</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>*</th><th>*</th><th>*</th></tr>
+<tr><td>web_api-user</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>*</th><th>*</th><th>*</th></tr>
+<tr><td>web_api-password</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>*</th><th>*</th><th>*</th></tr>
+<tr><td>manuals</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>tags</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>language</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th><th>-</th></tr>
+<tr><td>test_query-result_dir</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th></tr>
+<tr><td>test_query-queries</td><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>-</th><th>+</th></tr>
+</table>
+
 =head2 Example:
 
   data_dir: /pmltq/data/dir/ # directory where the data are (this is also base directory for data layers)
   resources: /pmltq/resources/ # main directory with PML schemas
 
+  treebank_id: tbid
+
   db: # typical DB auth stuff
     name: treebank_db_name
     host: localhost
@@ -368,11 +530,19 @@ option C<db_name: 'abc'>.
         t-node/coref_gram.rf: t-node
     - name: tdata
       data: **/*.t.gz
-  
+
   web_api:
     user: webuser
     password: pwd
     url: 'https://serviceurl.com/'
+    dbserver: myserver
+
+  title: 'Treebank name'
+  description: 'Short trebank descrioprion'
+  language: cs
+  tags:
+    - mytag1
+    - mytag2
 
 =head1 AUTHORS
 
